@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -34,23 +34,29 @@ advtr <- function(advan,trans) {
 }
 
 write_capture <- function(x) {
-  if(length(x)==0) return(NULL)
+  if(length(x) == 0) return(NULL)
   i <- seq_along(x)
   paste0("_capture_[",i-1,"] = ", x[i], ";") 
 }
 
 ## These are arguments to mrgsim that
 ## can be stated in $SET and then passed to mrgsim
-set_args <- c("Req", "obsonly","mtime", "recsort",
+set_args <- c("Req", "obsonly", "recsort",
               "carry.out","Trequest","trequest")
 
 check_spec_contents <- function(x,crump=TRUE,warn=TRUE,...) {
   invalid <- setdiff(x,block_list)
   valid <- intersect(x,block_list)
   
-  if(sum("MAIN"  == x) > 1) stop("Only one $MAIN block allowed in the model.",call.=FALSE)
-  if(sum("ODE"   == x) > 1) stop("Only one $ODE block allowed in the model.",call.=FALSE)
-  if(sum("SET"   == x) > 1) stop("Only one $SET block allowed in the model.",call.=FALSE)
+  if(sum("MAIN"  == x) > 1){
+    stop("Only one $MAIN block allowed in the model.",call.=FALSE)
+  }
+  if(sum("ODE"   == x) > 1) {
+    stop("Only one $ODE block allowed in the model.",call.=FALSE)
+  }
+  if(sum("SET"   == x) > 1) {
+    stop("Only one $SET block allowed in the model.",call.=FALSE)
+  }
   
   if(warn) {
     warn_cmt <- length(intersect(c("INIT", "CMT", "VCMT"),x)) == 0
@@ -93,9 +99,15 @@ define_digits <- function(x) {
 }
 
 fixed_parameters <- function(x,fixed_type) {
-  if(length(x)==0) return("// No fixed parameters.")
-  if(is.null(fixed_type))  fixed_type <-  "define"
-  if(!(fixed_type %in% c("define", "const"))) stop("fixed_type must be either const or define.", call.=FALSE)
+  if(length(x)==0) {
+    return("// No fixed parameters.")
+  }
+  if(is.null(fixed_type)) {
+    fixed_type <-  "define"
+  }
+  if(!(fixed_type %in% c("define", "const"))) {
+    stop("fixed_type must be either const or define.", call.=FALSE)
+  }
   switch(fixed_type,
          `const` =  paste0("const double ", paste0(names(x) ,"= " ,unlist(x), ";")),
          `define` = paste0("#define ", names(x), "  (", define_digits(unlist(x)),")")
@@ -256,6 +268,37 @@ check_block_data <- function(x,env,pos) {
   return(NULL)
 }
 
+# Code for relocating Rcpp objects in PREAMBLE
+global_rcpp_reg <- "\\s*global\\s+(Rcpp::)?(Logical|Integer|Character|Numeric)(Vector|Matrix)\\s+(\\w+?)\\s*(=.*;)"
+global_rcpp_sub <- "\\s*global\\s+(Rcpp::)?(Logical|Integer|Character|Numeric)(Vector|Matrix)\\s+"
+
+declare_rcpp_globals <- function(x) {
+  paste0("Rcpp::", x[3], x[4], " ", x[5], ";")
+}
+
+get_rcpp_globals <- function(x) {
+  m <- regmatches(x,regexec(global_rcpp_reg, x, perl = TRUE))
+  w <- which(sapply(m,length) > 0)
+  vars <- declare <-  character(0)
+  if(length(w) > 0) {
+    vars <- sapply(m[w],  "[", 5L)
+    x[w] <- gsub(global_rcpp_sub, "", x[w])
+    declare <- sapply(m[w], declare_rcpp_globals)
+  }
+  list(x = x, m = m, w = w, vars = vars, declare = declare) 
+}
+
+global_rcpp <- function(spec) {
+  x <- spec[["PREAMBLE"]]
+  globals <- get_rcpp_globals(x)
+  if(length(globals[["vars"]]) > 0) {
+    spec[["PREAMBLE"]] <- globals[["x"]]
+    spec[["GLOBAL"]] <- c(wrap_namespace(globals[["declare"]],NULL), spec[["GLOBAL"]])
+  }
+  spec
+}
+
+
 parse_ats <- function(x) {
   
   if(length(x)==0) return(list())
@@ -321,8 +364,8 @@ scrape_opts <- function(x,envir=list(),def=list(),all=TRUE,marker="=",narrow=TRU
   
   opts <- c(gsub(">>","", x[opts], fixed=TRUE))
   
-  opts <- merge(def, tolist(opts,envir=envir),
-                open=all,warn=FALSE,context="opts")
+  opts <- merge.list(def, tolist(opts,envir=envir),
+                     open=all,warn=FALSE,context="opts")
   
   opts <- c(opts,at)
   
@@ -491,7 +534,7 @@ handle_spec_block.specTABLE <- function(x,env,...) {
   
 }
 
-##' Functions to parse code blocks.
+##' Functions to parse code blocks
 ##' 
 ##' Most of the basic blocks are listed in this help topic.  
 ##' But see also \code{\link{PKMODEL}} which has more-involved 
@@ -500,6 +543,7 @@ handle_spec_block.specTABLE <- function(x,env,...) {
 ##' @param x data
 ##' @param env parse environment
 ##' @param annotated logical
+##' @param covariates logical
 ##' @param name block name
 ##' @param pos block position
 ##' @param ... passed
@@ -511,7 +555,7 @@ handle_spec_block.specTABLE <- function(x,env,...) {
 NULL
 
 ##' @rdname BLOCK_PARSE
-PARAM <- function(x,env,annotated=FALSE,pos=1,...) {
+PARAM <- function(x,env,annotated=FALSE,covariates=FALSE,pos=1,...) {
   
   check_block_data(x,env$ENV,pos)
   
@@ -525,6 +569,12 @@ PARAM <- function(x,env,annotated=FALSE,pos=1,...) {
     env[["param"]][[pos]] <- x
   }
   
+  if(covariates) {
+    env[["covariates"]] <- c(
+      env[["covariates"]], names(env[["param"]][[pos]])
+    )
+  }
+  
   return(NULL)
 }
 
@@ -668,7 +718,7 @@ CAPTURE <- function(x,env,annotated=FALSE,pos=1,...) {
 
 ##' @export
 handle_spec_block.specCAPTURE <- function(x,...) {
-  scrape_and_call(x,pass="CAPTURE",narrow=FALSE,...)
+  scrape_and_call(x,pass="CAPTURE",narrow=TRUE,...)
 }
 
 ##' @export
@@ -724,7 +774,9 @@ handle_spec_block.specPLUGIN <- function(x,env,...) {
 
 ##' Parse PKMODEL BLOCK data.
 ##' @param cmt compartment names as comma-delimited character
-##' @param ncmt number of compartments; must be 1 (one-compartment, not including a depot dosing compartment) or 2 (two-compartment model, not including a depot dosing compartment)
+##' @param ncmt number of compartments; must be 1 (one-compartment, 
+##' not including a depot dosing compartment) or 2 (two-compartment model, 
+##' not including a depot dosing compartment)
 ##' @param depot logical indicating whether to add depot compartment
 ##' @param trans the parameterization for the PK model; must be 1, 2, 4, or 11
 ##' @param env parse environment
@@ -732,8 +784,9 @@ handle_spec_block.specPLUGIN <- function(x,env,...) {
 ##' @param ... not used
 ##'
 ##' @details
-##' When using \code{$PKMODEL}, certain symbols must be defined in the model specification depending
-##' on the value of \code{ncmt}, \code{depot} and \code{trans}.
+##' When using \code{$PKMODEL}, certain symbols must be defined in the 
+##' model specification depending on the value of \code{ncmt}, \code{depot} 
+##' and \code{trans}.
 ##'
 ##' \itemize{
 ##' \item \code{ncmt} 1, \code{depot FALSE}, trans 2: \code{CL}, \code{V}
@@ -743,7 +796,9 @@ handle_spec_block.specPLUGIN <- function(x,env,...) {
 ##'
 ##' }
 ##'
-##' If \code{trans=11} is specfied, use the symbols listed above for the \code{ncmt} / \code{depot} combination, but append \code{i} at the end (e.g. \code{CLi} or \code{Qi} or \code{KAi}).
+##' If \code{trans=11} is specfied, use the symbols listed above for the 
+##' \code{ncmt} / \code{depot} combination, but append \code{i} at the end 
+##' (e.g. \code{CLi} or \code{Qi} or \code{KAi}).
 ##'
 ##' If \code{trans=1}, the user must utilize the following symbols:
 ##'
@@ -791,7 +846,9 @@ collect_subr <- function(x,what=c("PKMODEL")) {
   
   y <- x[names(x) %in% what]
   
-  if(length(y) >  1) stop("Only one $PKMODEL block is allowed.",call.=FALSE)
+  if(length(y) >  1) {
+    stop("Only one $PKMODEL block is allowed.",call.=FALSE)
+  }
   if(length(y) == 0) return(ans)
   ## Get rid of this once ADVANn are deprecated
   if(names(y) %in% c("PKMODEL")) {
@@ -799,8 +856,12 @@ collect_subr <- function(x,what=c("PKMODEL")) {
   }
   
   if(ans[["advan"]] != 13) {
-    if(any(is.element(c("VCMT"),names(x)))) stop("Found $VCMT and $PKMODEL in the same control stream.")
-    if(any(is.element("ODE", names(x)))) stop("Found $ODE and $PKMODEL in the same control stream.")
+    if(any(is.element(c("VCMT"),names(x)))) {
+      stop("Found $VCMT and $PKMODEL in the same control stream.")
+    }
+    if(any(is.element("ODE", names(x)))) {
+      stop("Found $ODE and $PKMODEL in the same control stream.")
+    }
   }
   
   ans[["n"]] <- ans[["advan"]] - as.integer(ans[["advan"]] > 2)
@@ -835,7 +896,7 @@ pick_advan <- function(ncmt,depot) {
 }
 
 check_pred_symbols <- function(x,code) {
-  p <- pars(x)
+  p <- Pars(x)
   code <- unlist(get_tokens(code,TRUE))
   have <- unique(c(p,code))
   
@@ -864,6 +925,7 @@ parse_env <- function(n,ENV=new.env()) {
   mread.env$namespace <- vector("list", n)
   mread.env$capture <- vector("list",n)
   mread.env$error <- character(0)
+  mread.env$covariates <- character(0)
   mread.env$ENV <- ENV 
   mread.env
 }
@@ -936,43 +998,8 @@ capture_param <- function(annot,.capture) {
     .capture <- intersect(.capture,what[,"name"])
     what[["block"]] <- "CAPTURE"
   }
-
+  
   annot <- dplyr::filter(annot, !(block=="CAPTURE" & name %in% .capture))
   bind_rows(annot,what)
 }
 
-##' @export
-handle_spec_block.specCOVSET <- function(x,...) {
-  stop("$COVSET is not a valid block.")
-  # require_covset()
-  # return(x)
-}
-
-handle_cov <- function(spec,envir) {
-  return(invisible(NULL))
-  # where <- which(names(spec)=="COVSET")
-  # value <- vector(mode="list",length=length(where))
-  # x <- vector(mode="character",length=length(where))
-  # 
-  # for(i in seq_along(where)) {
-  #   y <- scrape_opts(spec[[where[i]]])
-  #   xx <- lapply(y$x,dmutate::new_covobj)
-  #   value[[i]] <- do.call(dmutate::covset,xx)
-  #   if(is.null(y$name)) {
-  #     stop("All $COVSET blocks must have name block option set (e.g. $COVSET @name cov1)",call.=FALSE) 
-  #   }
-  #   x[i] <- y$name
-  # }
-  # 
-  # for(i in seq_along(x)) {
-  #   if(exists(x[i],envir)) {
-  #     stop("Can't assign covset ", 
-  #          x[i], 
-  #          ": an object already exists with that name",call.=FALSE) 
-  #   }
-  #   assign(x[i],value[[i]],envir=envir)  
-  # }
-  # return(invisible(NULL))
-}
-
-
