@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -25,36 +25,31 @@ context("test-rng")
 
 mod <- mrgsolve:::house(omega=diag(c(1,1,1,1)))
 
-out1 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
-out2 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
-set.seed(333)
-out3 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
-set.seed(333)
-out4 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
-
-out5 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20),seed=555)
-out6 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20),seed=555)
-
-
-
-
 ident <- function(x,y,...) {
-  x@date <- y@date <- date()
   identical(x,y) 
 }
 
-test_that("Runs with different seeds give different results without call to set.seed()", {
+test_that("Different seeds give different results without call to set.seed()", {
+  out1 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
+  out2 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
   expect_false(ident(out1,out2))
 })
 
-test_that("Runs with different seeds give different results with different calls to set.seed()", {
-  expect_false(ident(out3,out5))
+test_that("Different seeds give different results with different calls to set.seed()", {
+  set.seed(112)
+  out1 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
+  set.seed(333)
+  out2 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
+  expect_false(ident(out1,out2))
 })
-test_that("Runs with same seeds give same results with call to set.seed()", {
-  expect_true(ident(out3,out4))
-})
-test_that("Runs with same seeds give same results when seed passed to mrgsim()", {
-  expect_true(ident(out5,out6))
+
+test_that("Same seeds give same results with call to set.seed()", {
+  set.seed(112)
+  out1 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
+  set.seed(112)
+  out2 <- mrgsim(mod %>% init(GUT=100), idata=data.frame(ID=1:20))
+  expect_true(ident(out1,out1))
 })
 
 
+
